==> knt_ui-1.7.0.tar.gz: lib/src/ui_ext.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:fluttertoast/fluttertoast.dart';

import '../generated/colors.gen.dart';
import 'widget/knt_progress_bar.dart';

extension KntUiExt on BuildContext {
  void onDismiss() {
    Navigator.of(this).pop();
  }

  void onLoading({
    String? loadingMessage,
    Function()? onCancel,
  }) {
    showDialog(
      barrierDismissible: false,
      context: this,
      builder: (context) {
        return AlertDialog(
          contentPadding: const EdgeInsets.all(0.0),
          content: Container(
            padding: EdgeInsets.symmetric(
              vertical: 16.w,
              horizontal: 20.w,
            ),
            decoration: BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.circular(40.w),
            ),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Row(
                  children: [
                    KntProgressBar(),
                    SizedBox(width: 16.w),
                    Expanded(
                      child: Text(
                        loadingMessage ?? 'Loading',
                        style: TextStyle(
                          color: ColorName.tundora,
                          fontSize: 16.sp,
                          height: 21.sp / 16.sp,
                          fontWeight: FontWeight.w600,
                        ),
                      ),
                    ),
                    SizedBox(width: 16.w),
                    if (onCancel != null)
                      InkWell(
                        onTap: () {
                          onCancel.call();
                          context.onDismiss();
                        },
                        child: Container(
                          width: 48.w,
                          height: 48.w,
                          alignment: Alignment.centerRight,
                          child: Icon(
                            Icons.close,
                            size: 24.w,
                            color: ColorName.radicalRed,
                          ),
                        ),
                      ),
                  ],
                ),
              ],
            ),
          ),
        );
      },
    );
  }

  void onError(
    String message, {
    ShowMode mode = ShowMode.snackBar,
    int durationInSeconds = 2,
  }) {
    switch (mode) {
      case ShowMode.toast:
        Fluttertoast.showToast(
          msg: message,
          toastLength: Toast.LENGTH_SHORT,
          timeInSecForIosWeb: durationInSeconds,
          gravity: ToastGravity.SNACKBAR,
          fontSize: 16.sp,
        );
        break;
      case ShowMode.snackBar:
        ScaffoldMessenger.of(this).removeCurrentSnackBar();
        ScaffoldMessenger.of(this).showSnackBar(SnackBar(
          duration: Duration(seconds: durationInSeconds),
          content: Text(message),
        ));
        break;
    }
  }
}

enum ShowMode { toast, snackBar }

==> knt_ui-2.0.0.tar.gz: lib/src/ui_ext.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:fluttertoast/fluttertoast.dart';

import '../generated/colors.gen.dart';
import 'widget/knt_progress_bar.dart';

extension KntUiExt on BuildContext {
  void onDismiss() {
    Navigator.of(this).pop();
  }

  void onLoading({
    String? loadingMessage,
    void Function()? onCancel,
  }) {
    showDialog<void>(
      barrierDismissible: false,
      context: this,
      builder: (context) {
        return AlertDialog(
          contentPadding: EdgeInsets.zero,
          content: Container(
            padding: EdgeInsets.symmetric(
              vertical: 16.w,
              horizontal: 20.w,
            ),
            decoration: BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.circular(40.w),
            ),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Row(
                  children: [
                    const KntProgressBar(),
                    SizedBox(width: 16.w),
                    Expanded(
                      child: Text(
                        loadingMessage ?? 'Loading',
                        style: TextStyle(
                          color: ColorName.tundora,
                          fontSize: 16.sp,
                          height: 21.sp / 16.sp,
                          fontWeight: FontWeight.w600,
                        ),
                      ),
                    ),
                    SizedBox(width: 16.w),
                    if (onCancel != null)
                      InkWell(
                        onTap: () {
                          onCancel.call();
                          context.onDismiss();
                        },
                        child: Container(
                          width: 48.w,
                          height: 48.w,
                          alignment: Alignment.centerRight,
                          child: Icon(
                            Icons.close,
                            size: 24.w,
                            color: ColorName.radicalRed,
                          ),
                        ),
                      ),
                  ],
                ),
              ],
            ),
          ),
        );
      },
    );
  }

  void onError(
    String message, {
    ShowMode mode = ShowMode.snackBar,
    int durationInSeconds = 2,
  }) {
    switch (mode) {
      case ShowMode.toast:
        Fluttertoast.showToast(
          msg: message,
          toastLength: Toast.LENGTH_SHORT,
          timeInSecForIosWeb: durationInSeconds,
          gravity: ToastGravity.SNACKBAR,
          fontSize: 16.sp,
        );
        break;
      case ShowMode.snackBar:
        ScaffoldMessenger.of(this).removeCurrentSnackBar();
        ScaffoldMessenger.of(this).showSnackBar(
          SnackBar(
            duration: Duration(seconds: durationInSeconds),
            content: Text(message),
          ),
        );
        break;
    }
  }
}

enum ShowMode { toast, snackBar }
